#!/bin/sh
#
# Component: cases
#
# Purpose:
#     Handles STORESCPREG released events
#
# Usage:
#    onStorescpRegReleased.sh -t <type> -e <event> -i <id>
#
#    -t type  : Object type to be released. It will always be "STORESCPREG"
#    -e event : Event triggered runiing this script. It will always be "RELASED"
#    -i id    : Identifies the objectfile object (=<Study Instance UID> + "/" + <filename>)
#
# Description:
#     Will be called when a STORESCPREG reference counter is released.
# The DICOM object will be removed from the $IMAGE_TMP directory
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh


# onStorescpRegReleased.sh can be called directly:
# run as a task instead
if [ `basename $0` = "onStorescpRegReleased.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


LOGGER="/usr/bin/logger"
TAG="onStorescpRegReleased[$$]"

object=""
type=""
event=""
errMsg=""

while getopts 'e:t:i:' OPT; do
	case $OPT in
	e) event="$OPTARG" ;;
	t) type="$OPTARG" ;;
	i) object="$OPTARG" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

run_()
{
	if [ "$type" != "STORESCPREG" -o "$event" != "RELEASED" -o -z "$object" -o -n "$errMsg" ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Invalid argument: Type: $type; Event: $event; Objectfile: $object; $errMsg"
		return 125;
	fi

	eval `awk -vFS="_" '{print "numFields=" NF; for (i = 1; i <= NF; i++) { print "field" i "=" $i } }' <<<"$object"`
	if [ $numFields -eq 2 ] ; then
		fname=`sed 's;/;_;' <<<"$object"`
		[ -f "$IMAGE_TMP/$fname" ] && rm "$IMAGE_TMP/$fname"		
	else
		fname=$REPOSITORY_DATA_DICOM/${field1}/tmp/${field2}_${field3}
		[ -f "$fname" ] && rm "$fname"
	fi
}

# override print_
print_()
{
	echo "Handles Stored DICOM Object released event: Type: $type; Event: $event: Object: $object"
}



# override get_watson_message_
get_watson_message_()
{
	fname=`sed 's;/;_;' <<<"$object"`
	[ -z "$DR_WATSON_ID" ] && DR_WATSON_ID="onstorescpregreleased.$fname"
	[ -z "$DR_WATSON_MESSAGE" ] && DR_WATSON_MESSAGE="handling stored dicom object released event: $fname"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DR_WATSON_ID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DR_WATSON_MESSAGE"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DR_WATSON_MESSAGE [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DR_WATSON_ID.$RETRY_NUM"
	fi
} # get_watson_message_()
