#!/bin/sh
#
# usage: printrep.sh [-d pdfFile] [-f] -u <userid> [-c CPARAM] [-J faxNumber] studyUid [params_for_lp]
#
# -d means pdf generation instead of printing
#
. ~/etc/setenv.sh

# if called directly:
# run as a task instead
if [ `basename $0` = "printrepTask.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi

LOGGER="/usr/bin/logger"
TAG="printrepTask[$$]"

CPARAM=""
FAX=""
FAXNO=""
PDFFILE=""

if [ "$1" == '-d' ]; then
	shift
	PDFFILE="$1"
	shift
fi

if [ "$1" == '-f' ]; then
  FAX="yes"
  shift
fi

if [ "$1" == '-u' ]; then
	LOG_USER=$2
	shift
	shift
else
	$LOGGER -p $LOG_FACILITY.error -t "$TAG" "the userid parameter is missing"
	exit 1
fi

if [ "$1" == '-c' ]; then
  CPARAM='&'$2
  shift
  shift
fi

STYIUID=$1
shift

if [ "$1" == '-printPDF' ]; then
	wkhtmltopdfPrintsPdf="true"
	shift
fi

if [ "$1" == '-J' ]; then
  FAXNO=$2
#changing to -o "phone=..."  
  shift
  shift
fi  
 
LP_PARAMS="$@"
 	
# override run_ method
run_()
{
	#$LOGGER -p $LOG_FACILITY.debug -t "$TAG" ""

	rm /tmp/printrep.log.* 2>/dev/null
	
	PATH=$PATH:/usr/X11R6/bin
	
	# log in as system
	
	. $CONF/serverid.cfg
	LOGIN_SESSION="print.session_$SELF_SERVER_ID"
	DATE_TIME="`date +'%Y/%m/%d %H:%M:%S'`"
	
	echo "REPLACE $SESSIONTBL SET SID='$LOGIN_SESSION', SIGNON='$DATE_TIME',
	   LASTSEEN='$DATE_TIME', USERID='print_action', SIGNSTAT='S', IPADDR='$SERVERIP';" | \
	   $MYSQL_HOME/bin/mysql -N $DBNAME 2>/dev/null
	   
	USER_PART=""
	
	[ -n "${LOG_USER}" ] && USER_PART="&cActingUser=${LOG_USER}"
	
	gwpTimeout1=30
	gwpTimeout2=10
	
	[ -f $CONF/printRep.cfg ] && . $CONF/printRep.cfg

	output="/tmp/printrep.$$.ps"

	if [ "$PDFFILE" == "" -a "true" == "$forceHtml2Ps" -a "`command -v html2ps`" != "" ] ; then
		echo "
		@html2ps {
		  option {
		      toc: 0
		      titlepage: 0
		      hyphenate: 0
		  }
		  footer {
		    left: \$T;
		    right: \"Page \$N\";
		    center: \"\";
		  }
		}
		" >/tmp/printer.html2ps.1.conf.$$
		echo "
		@html2ps {
		  package {
		      geturl: \"$CURL_HOME/bin/curl -i -L --cookie 'sessionid=$LOGIN_SESSION' \"
		  }
		}
		" >/tmp/printer.html2ps.2.conf.$$
	
		CONFFILE="/tmp/printer.html2ps.1.conf.$$"
	
		if [ -f "$CONF/html2psrc" ] ; then
		  CONFFILE="${CONFFILE}:${CONF}/html2psrc"
		fi
	
		CONFFILE="${CONFFILE}:/tmp/printer.html2ps.2.conf.$$"
	
		html2ps -o $output -f "$CONFFILE" "http://127.0.0.1:$HTTP_PORT/cases/reportview.jsp?cGr=$STYIUID&cPrintFriendly=true&cFax=$FAX&cFaxNo=$FAXNO${CPARAM}${USER_PART}" >/tmp/printrep.log.$$ 2>&1
	
		rm /tmp/printer.html2ps.1.conf.$$
		rm /tmp/printer.html2ps.2.conf.$$
	
	else
		outputpdf="/tmp/printrep.$$.pdf"
		[ "" != "$PDFFILE" ] && output="$PDFFILE"
	
		EXTRAPARAMS="-s Letter"
		[ -f $CONF/wkhtmltopdf.cfg ] && EXTRAPARAMS=`cat $CONF/wkhtmltopdf.cfg`

		eval "$EXTTOOLS_HOME/timelimit -q -t $gwpTimeout1 -T $gwpTimeout2 wkhtmltopdf $EXTRAPARAMS \"http://$SERVERIP:$HTTP_PORT/cases/reportview.jsp?sessionid=${LOGIN_SESSION}&cGr=$STYIUID&cPrintFriendly=true&cFax=$FAX&cDontPrint=true&cFaxNo=$FAXNO${CPARAM}${USER_PART}\" $outputpdf" >/tmp/printrep.log.$$ 2>&1
		res=$?
		if [ $res -gt 0 ] ; then
			if [ $res -gt 127 ] ; then
				$LOGGER -p $LOG_FACILITY.error -t "$TAG" "wkhtmltopdf timed out generating report of study $STYIUID"
			else
				$LOGGER -p $LOG_FACILITY.error -t "$TAG" "wkhtmltopdf returned error $res generating report of study $STYIUID"
			fi
		return 1
		fi
		
		[ "$PDFFILE" != "" ] && return 0
			
		if [ "$wkhtmltopdfPrintsPdf" == "true" ] ; then
			output="$outputpdf"
		else
			# convert pdf to PS for backward compatibility
			pdftops $outputpdf $output
			rm $outputpdf
		fi
	fi
	
			
	if [ "$FAX" == "yes" ] ; then
		echo "/usr/bin/lpr -o phone=$FAXNO $LP_PARAMS $output" >/home/medsrv/var/log/fax.log 
		/usr/bin/lpr -o phone=$FAXNO $LP_PARAMS $output
	else
		/usr/bin/lp $LP_PARAMS $output
	fi
	
	rm $output
	return 0
}

get_resources_()
{
	echo "System.CPU"
}

get_display_name_()
{
	if [ "$FAX" == "yes" ] ; then
		echo "Fax report action retry task"
	else
		echo "Print report action retry task"
	fi
}

get_property_() {
	if [ "$PROPERTY" = "1PST" -a -n "$STYIUID" ] ; then
		echo -n "$STYIUID"
		return 0
	fi

	get_def_property_
}

