#!/bin/sh
#
# Component: cases
#
# OBSOLETE: use cases.CommitmentSender instead
#
# Purpose:
#    Sends storage commitment to a device
#
#  sendCommitment.sh -H <hostid> -s <study> -f <file>
#
#   <hostid> : ID of the device to send commitment. <hostid> has two form:
#                 - ID from the Devices (Target) table
#                 - IP:AETitle for unrecognized devices (promiscuous mode)
#   <study>  : Study Insance UID of the study where the file belongs to
#   <file>   : file name to be committed
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh


# if sendCommitment.sh is called directly:
# run as a task instead
if [ `basename $0` = "sendCommitment.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


LOGGER="/usr/bin/logger"
TAG="sendCommitment[$$]"

ErrMsg=""

# Parameters

Study=""
File=""
Host=""
INPUT_PARAMS=""

while getopts 'f:s:H:' OPT; do
	case $OPT in
		# -f has been changed to -o in CommitmentSender
		f) File="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -o \"$OPTARG\"" ;;
		s) Study="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -s \"$OPTARG\"" ;;
		H) Host="$OPTARG" ; INPUT_PARAMS="$INPUT_PARAMS -H \"$OPTARG\"" ;;
		*) ErrMsg="Invalid_Parameter:$OPT" ;;
	esac
done


[ -f "$CONF/taskd.rc" ] && . $CONF/taskd.rc

command="${CASES_HOME#$HOME/component/}.CommitmentSender $INPUT_PARAMS"

run_()
{
	$TASKD_HOME/runjavacmd -c "0 $command" -p $JAVA_SERVER_PORT
	ERR=$?
	
	exit $ERR
} # run_()


# override print_
print_()
{
	$TASKD_HOME/runjavacmd -c "print $command" -p $JAVA_SERVER_PORT
}

# override cleanup_
cleanup_()
{
	$TASKD_HOME/runjavacmd -c "cleanup $command" -p $JAVA_SERVER_PORT
}

# override get_watson_message_
get_watson_message_()
{
	[ -z "$DR_WATSON_ID" ] && DR_WATSON_ID="sendCommitment.$Host"
	[ -z "$DR_WATSON_MESSAGE" ] && DR_WATSON_MESSAGE="Can not start sending commitment to $Host"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DR_WATSON_ID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DR_WATSON_MESSAGE"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DR_WATSON_MESSAGE [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DR_WATSON_ID.$RETRY_NUM"
	fi
} # get_watson_message_()

