package imagemed.layout.validator;

import java.text.Format;
import java.util.Properties;

import com.erad.pacs.services.usermanager.client.Session;

import imagemed.util.LocalizedMessage;


public class DefaultDoctypeValidator extends DBValidator {

	@Override
	protected void preValidate( Session session ) {

		setMandatoryError( "DTNA" );
		setMandatoryError( "DTUI" );
	}


	@Override
	public void validate( Session session ) {

		mustBeUnique( session, "DTNA", m_doctypePage );
		mustBeUnique( session, "DTUI", m_doctypePage );

		// error for changing id=0
		String actValue = m_rootRec.getCurrentValue( "DTUI", "" );
		String oldValue = m_rootRec.getOldValue( "DTUI", "" );
		if ( "0".equals( oldValue ) && !"0".equals( actValue ) ) {
			m_errors.add( LocalizedMessage.getSimpleMessage( "DEFAULT_DOCTYPE_VALIDATOR_ZERO_ID_UNDEFINED_CHANGED" ) );
		}

		// warning for 2 or more records for the same group
		Properties groupnames = new Properties();
		for ( RecordIterator group = getIterator( m_doctypeGroupTable ); group.next( session ); ) {
			String name = group.getValue( session, "DGNA" );
			if ( name != null ) {
				if ( "Exists".equals( groupnames.getProperty( name ) ) ) {
					m_warnings.add( LocalizedMessage.getCompoundMessage( "DEFAULT_DOCTYPE_VALIDATOR_TWO_OR_MORE_GROUP", new Format[]{ null }, new Object[]{ name }, false ) );
					groupnames.setProperty( name, "Warninged" );
				}
				else if ( groupnames.getProperty( name ) == null ) {
					groupnames.setProperty( name, "Exists" );
				}
			}
		}

		// warning for 2 or more records for the same user
		Properties usernames = new Properties();
		for ( RecordIterator user = getIterator( m_doctypeUserTable ); user.next( session ); ) {
			String name = user.getValue( session, "DUNA" );
			if ( name != null ) {
				if ( "Exists".equals( usernames.getProperty( name ) ) ) {
					m_warnings.add( LocalizedMessage.getCompoundMessage( "DEFAULT_DOCTYPE_VALIDATOR_TWO_OR_MORE_USER", new Format[]{ null }, new Object[]{ name }, false ) );
					usernames.setProperty( name, "Warninged" );
				}
				else if ( usernames.getProperty( name ) == null ) {
					usernames.setProperty( name, "Exists" );
				}
			}
		}

		// If this is the default of a page, set every other doctype not default of that page 
		if ( "yes".equals( m_rootRec.getCurrentValue( "DTQD", "no" ) ) ) {
			setEachRecordsValue( m_doctypeTable, "DTQD", "no", "DTUI", actValue );
		}

		// The same for Upload 
		if ( "yes".equals( m_rootRec.getCurrentValue( "DTQU", "no" ) ) ) {
			setEachRecordsValue( m_doctypeTable, "DTQU", "no", "DTUI", actValue );
		}

	}

}
